# -*- coding: utf-8 -*-
# Copyright © 2023 Contrast Security, Inc.
# See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: settings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='settings.proto',
  package='contrast.api.settings',
  syntax='proto3',
  serialized_options=b'Z<bitbucket.org/contrastsecurity/go-speedracer-go/from_service',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0esettings.proto\x12\x15\x63ontrast.api.settings\"\x8d\x04\n\x10\x41pplicationState\x12\x12\n\ncreated_ms\x18\x01 \x01(\x03\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x14\n\x0c\x61pp_language\x18\x03 \x01(\t\x12\x10\n\x08\x61pp_path\x18\x04 \x01(\t\x12\x11\n\tapp_group\x18\x10 \x01(\t\x12\x10\n\x08\x61pp_tags\x18\x11 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x12 \x01(\t\x12>\n\x0fserver_features\x18\x06 \x01(\x0b\x32%.contrast.api.settings.ServerFeatures\x12H\n\x14\x61pplication_settings\x18\x07 \x01(\x0b\x32*.contrast.api.settings.ApplicationSettings\x12H\n\x14\x61\x63\x63umulator_settings\x18\x08 \x01(\x0b\x32*.contrast.api.settings.AccumulatorSettings\x12\x13\n\x0bserver_name\x18\t \x01(\t\x12\x13\n\x0bserver_path\x18\n \x01(\t\x12\x13\n\x0bserver_type\x18\x0b \x01(\t\x12\x13\n\x0bserver_tags\x18\r \x01(\t\x12\x1a\n\x12server_environment\x18\x0e \x01(\t\x12\x16\n\x0eserver_version\x18\x0f \x01(\t\x12\x15\n\ragent_version\x18\x0c \x01(\t\"\xee\x02\n\rAgentSettings\x12\x0f\n\x07sent_ms\x18\x01 \x01(\x03\x12>\n\x0fserver_features\x18\x02 \x01(\x0b\x32%.contrast.api.settings.ServerFeatures\x12H\n\x14\x61pplication_settings\x18\x03 \x01(\x0b\x32*.contrast.api.settings.ApplicationSettings\x12H\n\x14\x61\x63\x63umulator_settings\x18\x04 \x01(\x0b\x32*.contrast.api.settings.AccumulatorSettings\x12:\n\rprotect_state\x18\x05 \x01(\x0b\x32#.contrast.api.settings.ProtectState\x12<\n\x0einput_analysis\x18\x06 \x01(\x0b\x32$.contrast.api.settings.InputAnalysis\"i\n\x0cProtectState\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\rtrack_request\x18\x04 \x01(\x08\x12\x1a\n\x12security_exception\x18\x02 \x01(\x08\x12\x18\n\x10security_message\x18\x03 \x01(\t\"\xe0\x03\n\x0eServerFeatures\x12\r\n\x05\x63\x61\x63he\x18\x01 \x01(\x08\x12\x10\n\x08log_file\x18\x02 \x01(\t\x12\x11\n\tlog_level\x18\x03 \x01(\t\x12;\n\tinventory\x18\x04 \x01(\x0b\x32(.contrast.api.settings.InventoryFeatures\x12\x35\n\x06\x61ssess\x18\x05 \x01(\x0b\x32%.contrast.api.settings.AssessFeatures\x12\x35\n\x06\x64\x65\x66\x65nd\x18\x06 \x01(\x0b\x32%.contrast.api.settings.DefendFeatures\x12W\n\x14instrumentation_mode\x18\x07 \x01(\x0e\x32\x39.contrast.api.settings.ServerFeatures.InstrumentationMode\x12\x44\n\x10\x63ontrast_service\x18\x08 \x01(\x0b\x32*.contrast.api.settings.ContrastServiceData\"P\n\x13InstrumentationMode\x12\r\n\tUNDEFINED\x10\x00\x12\x10\n\x0c\x41GENT_CONFIG\x10\x01\x12\n\n\x06\x44UPLEX\x10\x02\x12\x0c\n\x08PROFILER\x10\x03\"&\n\x13\x43ontrastServiceData\x12\x0f\n\x07version\x18\x01 \x01(\t\"\xf9\x02\n\x13\x41pplicationSettings\x12<\n\x0fvirtual_patches\x18\x02 \x03(\x0b\x32#.contrast.api.settings.VirtualPatch\x12?\n\x10protection_rules\x18\x03 \x03(\x0b\x32%.contrast.api.settings.ProtectionRule\x12\x34\n\nexclusions\x18\x05 \x03(\x0b\x32 .contrast.api.settings.Exclusion\x12\x1d\n\x15\x64isabled_assess_rules\x18\x06 \x03(\t\x12\x32\n\treactions\x18\x07 \x03(\x0b\x32\x1f.contrast.api.settings.Reaction\x12\x16\n\nsession_id\x18\x08 \x01(\tB\x02\x18\x01\x12\x42\n\rsqli_settings\x18\t \x01(\x0b\x32+.contrast.api.settings.SqlInjectionSettings\"\x98\x01\n\x14SqlInjectionSettings\x12\x1a\n\x12\x64\x65tect_tautologies\x18\x01 \x01(\x08\x12\x1e\n\x16\x64\x65tect_chained_queries\x18\x02 \x01(\x08\x12 \n\x18\x64\x65tect_suspicious_unions\x18\x03 \x01(\x08\x12\"\n\x1a\x64\x65tect_dangerous_functions\x18\x04 \x01(\x08\"\xc0\x01\n\x08Reaction\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x32\n\tlog_level\x18\x02 \x01(\x0e\x32\x1f.contrast.api.settings.LogLevel\x12<\n\toperation\x18\x03 \x01(\x0e\x32).contrast.api.settings.Reaction.Operation\"1\n\tOperation\x12\x08\n\x04NOOP\x10\x00\x12\x0b\n\x07\x44ISABLE\x10\x01\x12\r\n\tINVENTORY\x10\x02\"\xc2\x01\n\x13\x41\x63\x63umulatorSettings\x12R\n\x0c\x61\x63\x63umulators\x18\x01 \x03(\x0b\x32<.contrast.api.settings.AccumulatorSettings.AccumulatorsEntry\x1aW\n\x11\x41\x63\x63umulatorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".contrast.api.settings.Accumulator:\x02\x38\x01\"}\n\x11InventoryFeatures\x12\x11\n\tlibraries\x18\x01 \x01(\x08\x12\x10\n\x08\x61\x63tivity\x18\x02 \x01(\x08\x12\x12\n\nmonitor_db\x18\x03 \x01(\x08\x12\x14\n\x0cmonitor_ldap\x18\x04 \x01(\x08\x12\x19\n\x11monitor_web_calls\x18\x05 \x01(\x08\"\xde\x05\n\x0e\x41ssessFeatures\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0f\x64ynamic_sources\x18\x02 \x01(\x08\x12\x0f\n\x07sources\x18\x03 \x01(\x08\x12\r\n\x05rules\x18\x04 \x01(\x08\x12\x13\n\x0bpropagators\x18\x05 \x01(\x08\x12\x0f\n\x07taggers\x18\x06 \x01(\x08\x12\x19\n\x11response_scanning\x18\x07 \x01(\x08\x12I\n\x0bstacktraces\x18\x08 \x01(\x0e\x32\x34.contrast.api.settings.AssessFeatures.SaveStacktrace\x12\x18\n\x10validator_scopes\x18\t \x01(\x08\x12\x18\n\x10identity_tagging\x18\n \x01(\x08\x12<\n\nsanitizers\x18\x0b \x03(\x0b\x32(.contrast.api.settings.CustomRuleFeature\x12<\n\nvalidators\x18\x0c \x03(\x0b\x32(.contrast.api.settings.CustomRuleFeature\x12\x1a\n\x0e\x64isabled_rules\x18\r \x03(\tB\x02\x18\x01\x12\x31\n\x08sampling\x18\x0e \x01(\x0b\x32\x1f.contrast.api.settings.Sampling\x12Y\n\x13\x64ynamic_sources_map\x18\x13 \x03(\x0b\x32<.contrast.api.settings.AssessFeatures.DynamicSourcesMapEntry\x1a^\n\x16\x44ynamicSourcesMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.contrast.api.settings.DynamicSource:\x02\x38\x01\"<\n\x0eSaveStacktrace\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x08\n\x04SOME\x10\x02\x12\x08\n\x04NONE\x10\x03\"=\n\x11\x43ustomRuleFeature\x12\x0b\n\x03\x61pi\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\x12\r\n\x05rules\x18\x03 \x03(\t\"w\n\x08Sampling\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x10\n\x08\x62\x61seline\x18\x02 \x01(\x05\x12\x11\n\twindow_ms\x18\x03 \x01(\x05\x12\x19\n\x11request_frequency\x18\x04 \x01(\x05\x12\x1a\n\x12response_frequency\x18\x05 \x01(\x05\"\xde\x01\n\rDynamicSource\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x13\n\x0bmethod_name\x18\x02 \x01(\t\x12\x17\n\x0finstance_method\x18\x03 \x01(\x08\x12\x0e\n\x06target\x18\x04 \x01(\t\x12H\n\nproperties\x18\x06 \x03(\x0b\x32\x34.contrast.api.settings.DynamicSource.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x04\n\x0e\x44\x65\x66\x65ndFeatures\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x13\n\x0b\x62ot_blocker\x18\x02 \x01(\x08\x12\x37\n\x0c\x62ot_blockers\x18\x03 \x03(\x0b\x32!.contrast.api.settings.BotBlocker\x12:\n\rip_blacklists\x18\x04 \x03(\x0b\x32\x1f.contrast.api.settings.IpFilterB\x02\x18\x01\x12\x35\n\x0cip_denylists\x18\n \x03(\x0b\x32\x1f.contrast.api.settings.IpFilter\x12:\n\rip_whitelists\x18\x05 \x03(\x0b\x32\x1f.contrast.api.settings.IpFilterB\x02\x18\x01\x12\x36\n\rip_allowlists\x18\x0b \x03(\x0b\x32\x1f.contrast.api.settings.IpFilter\x12\x39\n\rlog_enhancers\x18\x06 \x03(\x0b\x32\".contrast.api.settings.LogEnhancer\x12?\n\x10rule_definitions\x18\x07 \x03(\x0b\x32%.contrast.api.settings.RuleDefinition\x12-\n\x06syslog\x18\x08 \x01(\x0b\x32\x1d.contrast.api.settings.Syslog\x12)\n\x04\x61uth\x18\t \x01(\x0b\x32\x1b.contrast.api.settings.Auth\"\xc9\x05\n\x06Syslog\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x15\n\rfacility_code\x18\x04 \x01(\x05\x12\x45\n\x0f\x63onnection_type\x18\x05 \x01(\x0e\x32,.contrast.api.settings.Syslog.ConnectionType\x12\x42\n\x12severity_exploited\x18\x06 \x01(\x0e\x32&.contrast.api.settings.Syslog.Severity\x12@\n\x10severity_blocked\x18\x07 \x01(\x0e\x32&.contrast.api.settings.Syslog.Severity\x12?\n\x0fseverity_probed\x18\x08 \x01(\x0e\x32&.contrast.api.settings.Syslog.Severity\x12J\n\x1aseverity_blocked_perimeter\x18\x0b \x01(\x0e\x32&.contrast.api.settings.Syslog.Severity\x12I\n\x19severity_probed_perimeter\x18\x0c \x01(\x0e\x32&.contrast.api.settings.Syslog.Severity\x12\x10\n\x08protocol\x18\t \x01(\t\x12\x0c\n\x04host\x18\n \x01(\t\"C\n\x0e\x43onnectionType\x12\x0f\n\x0bUNENCRYPTED\x10\x00\x12\x11\n\tENCRYOTED\x10\x01\x1a\x02\x08\x01\x12\r\n\tENCRYPTED\x10\x02\"k\n\x08Severity\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05\x41LERT\x10\x01\x12\x0c\n\x08\x43RITICAL\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\n\n\x06NOTICE\x10\x05\x12\x08\n\x04INFO\x10\x06\x12\t\n\x05\x44\x45\x42UG\x10\x07\"G\n\nBotBlocker\x12\x0b\n\x03\x62ot\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x61se_sensitive\x18\x02 \x01(\x08\x12\x14\n\x0cstart_anchor\x18\x03 \x01(\x08\"Z\n\x08IpFilter\x12\x0f\n\x07\x65xpires\x18\x01 \x01(\x08\x12\x15\n\rexpires_at_ms\x18\x02 \x01(\x03\x12\n\n\x02ip\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04uuid\x18\x05 \x01(\t\"\xbe\x02\n\x0bLogEnhancer\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x61pi\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12>\n\tlog_level\x18\x05 \x01(\x0e\x32+.contrast.api.settings.LogEnhancer.LogLevel\x12<\n\x08log_type\x18\x06 \x01(\x0e\x32*.contrast.api.settings.LogEnhancer.LogType\"?\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x08\n\x04WARN\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"9\n\x07LogType\x12\r\n\tLOG_AUDIT\x10\x00\x12\r\n\tLOG_ERROR\x10\x01\x12\x10\n\x0cLOG_SECURITY\x10\x02\"\x94\x01\n\x0eRuleDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x08keywords\x18\x02 \x03(\x0b\x32\'.contrast.api.settings.StringDefinition\x12\x39\n\x08patterns\x18\x03 \x03(\x0b\x32\'.contrast.api.settings.StringDefinition\"\xd2\x01\n\x10StringDefinition\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.contrast.api.settings.StringDefinition.Type\x12\x0c\n\x04rule\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12\x10\n\x08\x64owncase\x18\x07 \x01(\t\x12\x16\n\x0e\x63\x61se_sensitive\x18\x05 \x01(\x08\x12\r\n\x05score\x18\x06 \x01(\x05\" \n\x04Type\x12\x0b\n\x07KEYWORD\x10\x00\x12\x0b\n\x07PATTERN\x10\x01\"\xc7\x04\n\tExclusion\x12<\n\x04type\x18\x01 \x01(\x0e\x32..contrast.api.settings.Exclusion.ExclusionType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\x0ematch_strategy\x18\x03 \x01(\x0e\x32..contrast.api.settings.Exclusion.MatchStrategyB\x02\x18\x01\x12\x11\n\x05modes\x18\x04 \x03(\tB\x02\x18\x01\x12\x18\n\x10protection_rules\x18\x05 \x03(\t\x12\x18\n\x10\x61ssessment_rules\x18\x06 \x03(\t\x12\x0c\n\x04urls\x18\x07 \x03(\t\x12\x15\n\tblacklist\x18\x08 \x03(\tB\x02\x18\x01\x12\x10\n\x08\x64\x65nylist\x18\r \x03(\t\x12>\n\ninput_type\x18\t \x01(\x0e\x32*.contrast.api.settings.Exclusion.InputType\x12\x12\n\ninput_name\x18\n \x01(\t\x12\x0e\n\x06\x61ssess\x18\x0b \x01(\x08\x12\x0f\n\x07protect\x18\x0c \x01(\x08\"-\n\rExclusionType\x12\x07\n\x03URL\x10\x00\x12\t\n\x05INPUT\x10\x01\x12\x08\n\x04\x43ODE\x10\x02\"\\\n\tInputType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06\x43OOKIE\x10\x01\x12\r\n\tPARAMETER\x10\x02\x12\n\n\x06HEADER\x10\x03\x12\x08\n\x04\x42ODY\x10\x04\x12\x0f\n\x0bQUERYSTRING\x10\x05\"\"\n\rMatchStrategy\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04ONLY\x10\x01\"\xb6\x02\n\x0cVirtualPatch\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12=\n\x07headers\x18\x04 \x03(\x0b\x32,.contrast.api.settings.VirtualPatchCondition\x12@\n\nparameters\x18\x05 \x03(\x0b\x32,.contrast.api.settings.VirtualPatchCondition\x12:\n\x04urls\x18\x06 \x03(\x0b\x32,.contrast.api.settings.VirtualPatchCondition\x12@\n\nconditions\x18\x07 \x03(\x0b\x32,.contrast.api.settings.VirtualPatchCondition\"\xbd\x03\n\x15VirtualPatchCondition\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12J\n\ninput_type\x18\x04 \x01(\x0e\x32\x36.contrast.api.settings.VirtualPatchCondition.InputType\x12K\n\nevaluation\x18\x05 \x01(\x0e\x32\x37.contrast.api.settings.VirtualPatchCondition.Evaluation\"h\n\tInputType\x12\x11\n\rUNKNOWN_INPUT\x10\x00\x12\r\n\tUSERAGENT\x10\x01\x12\x0b\n\x07REFERER\x10\x02\x12\x07\n\x03URL\x10\x03\x12\r\n\tPARAMETER\x10\x04\x12\n\n\x06HEADER\x10\x05\x12\x08\n\x04\x43ODE\x10\x06\"\x83\x01\n\nEvaluation\x12\x16\n\x12UNKNOWN_EVALUATION\x10\x00\x12\x0b\n\x07MATCHES\x10\x01\x12\x10\n\x0c\x44OESNT_MATCH\x10\x02\x12\x0c\n\x08\x43ONTAINS\x10\x03\x12\x12\n\x0e\x44OESNT_CONTAIN\x10\x04\x12\n\n\x06\x45QUALS\x10\x05\x12\x10\n\x0c\x44OESNT_EQUAL\x10\x06\"\xbb\x01\n\x0eProtectionRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x38\n\x04mode\x18\x03 \x01(\x0e\x32*.contrast.api.settings.ProtectionRule.Mode\"U\n\x04Mode\x12\r\n\tNO_ACTION\x10\x00\x12\x0b\n\x07MONITOR\x10\x01\x12\t\n\x05\x42LOCK\x10\x02\x12\x16\n\x12\x42LOCK_AT_PERIMETER\x10\x03\x12\x0e\n\x06PERMIT\x10\x04\x1a\x02\x08\x01\"x\n\x0b\x41\x63\x63umulator\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x11\n\twindow_ms\x18\x04 \x01(\x03\x12\x12\n\ncreated_ms\x18\x05 \x01(\x03\x12\x16\n\x0elast_update_ms\x18\x06 \x01(\x03\"T\n\x04\x41uth\x12.\n\x04mode\x18\x01 \x01(\x0e\x32 .contrast.api.settings.Auth.Mode\"\x1c\n\x04Mode\x12\x07\n\x03OFF\x10\x00\x12\x0b\n\x07MONITOR\x10\x01\"L\n\rInputAnalysis\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.contrast.api.settings.InputAnalysisResult\"\xd4\x05\n\x13InputAnalysisResult\x12\x0f\n\x07rule_id\x18\x01 \x01(\t\x12H\n\ninput_type\x18\x03 \x01(\x0e\x32\x34.contrast.api.settings.InputAnalysisResult.InputType\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\t\x12J\n\x0bscore_level\x18\t \x01(\x0e\x32\x35.contrast.api.settings.InputAnalysisResult.ScoreLevel\x12\x0b\n\x03ids\x18\x07 \x03(\t\x12\x14\n\x0c\x61ttack_count\x18\x08 \x01(\x05\"\x85\x03\n\tInputType\x12\x12\n\x0eUNDEFINED_TYPE\x10\x00\x12\x08\n\x04\x42ODY\x10\x01\x12\x0f\n\x0b\x43OOKIE_NAME\x10\x02\x12\x10\n\x0c\x43OOKIE_VALUE\x10\x03\x12\n\n\x06HEADER\x10\x04\x12\x12\n\x0ePARAMETER_NAME\x10\x05\x12\x13\n\x0fPARAMETER_VALUE\x10\x06\x12\x0f\n\x0bQUERYSTRING\x10\x07\x12\x07\n\x03URI\x10\x08\x12\n\n\x06SOCKET\x10\t\x12\x0e\n\nJSON_VALUE\x10\n\x12\x16\n\x12JSON_ARRAYED_VALUE\x10\x0b\x12\x1a\n\x16MULTIPART_CONTENT_TYPE\x10\x10\x12\x13\n\x0fMULTIPART_VALUE\x10\x11\x12\x18\n\x14MULTIPART_FIELD_NAME\x10\x12\x12\x12\n\x0eMULTIPART_NAME\x10\x13\x12\r\n\tXML_VALUE\x10\x14\x12\r\n\tDWR_VALUE\x10\x15\x12\n\n\x06METHOD\x10\x16\x12\x0b\n\x07REQUEST\x10\x17\x12\x11\n\rURL_PARAMETER\x10\x18\x12\x0b\n\x07UNKNOWN\x10\x63\"A\n\nScoreLevel\x12\x0c\n\x08\x44ONTCARE\x10\x00\x12\x11\n\rWORTHWATCHING\x10\x01\x12\x12\n\x0e\x44\x45\x46INITEATTACK\x10\x02*?\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x08\n\x04WARN\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x42>Z<bitbucket.org/contrastsecurity/go-speedracer-go/from_serviceb\x06proto3'
)

_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='contrast.api.settings.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5405,
  serialized_end=5468,
)
_sym_db.RegisterEnumDescriptor(_LOGLEVEL)

LogLevel = enum_type_wrapper.EnumTypeWrapper(_LOGLEVEL)
TRACE = 0
DEBUG = 1
INFO = 2
WARN = 3
ERROR = 4


_SERVERFEATURES_INSTRUMENTATIONMODE = _descriptor.EnumDescriptor(
  name='InstrumentationMode',
  full_name='contrast.api.settings.ServerFeatures.InstrumentationMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGENT_CONFIG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUPLEX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROFILER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1446,
  serialized_end=1526,
)
_sym_db.RegisterEnumDescriptor(_SERVERFEATURES_INSTRUMENTATIONMODE)

_REACTION_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='contrast.api.settings.Reaction.Operation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOOP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVENTORY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2247,
  serialized_end=2296,
)
_sym_db.RegisterEnumDescriptor(_REACTION_OPERATION)

_ASSESSFEATURES_SAVESTACKTRACE = _descriptor.EnumDescriptor(
  name='SaveStacktrace',
  full_name='contrast.api.settings.AssessFeatures.SaveStacktrace',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3297,
  serialized_end=3357,
)
_sym_db.RegisterEnumDescriptor(_ASSESSFEATURES_SAVESTACKTRACE)

_SYSLOG_CONNECTIONTYPE = _descriptor.EnumDescriptor(
  name='ConnectionType',
  full_name='contrast.api.settings.Syslog.ConnectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNENCRYPTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENCRYOTED', index=1, number=1,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENCRYPTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4865,
  serialized_end=4932,
)
_sym_db.RegisterEnumDescriptor(_SYSLOG_CONNECTIONTYPE)

_SYSLOG_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='contrast.api.settings.Syslog.Severity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4934,
  serialized_end=5041,
)
_sym_db.RegisterEnumDescriptor(_SYSLOG_SEVERITY)

_LOGENHANCER_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='contrast.api.settings.LogEnhancer.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5405,
  serialized_end=5468,
)
_sym_db.RegisterEnumDescriptor(_LOGENHANCER_LOGLEVEL)

_LOGENHANCER_LOGTYPE = _descriptor.EnumDescriptor(
  name='LogType',
  full_name='contrast.api.settings.LogEnhancer.LogType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_AUDIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG_SECURITY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5470,
  serialized_end=5527,
)
_sym_db.RegisterEnumDescriptor(_LOGENHANCER_LOGTYPE)

_STRINGDEFINITION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='contrast.api.settings.StringDefinition.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KEYWORD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATTERN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5859,
  serialized_end=5891,
)
_sym_db.RegisterEnumDescriptor(_STRINGDEFINITION_TYPE)

_EXCLUSION_EXCLUSIONTYPE = _descriptor.EnumDescriptor(
  name='ExclusionType',
  full_name='contrast.api.settings.Exclusion.ExclusionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='URL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPUT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6302,
  serialized_end=6347,
)
_sym_db.RegisterEnumDescriptor(_EXCLUSION_EXCLUSIONTYPE)

_EXCLUSION_INPUTTYPE = _descriptor.EnumDescriptor(
  name='InputType',
  full_name='contrast.api.settings.Exclusion.InputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COOKIE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BODY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUERYSTRING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6349,
  serialized_end=6441,
)
_sym_db.RegisterEnumDescriptor(_EXCLUSION_INPUTTYPE)

_EXCLUSION_MATCHSTRATEGY = _descriptor.EnumDescriptor(
  name='MatchStrategy',
  full_name='contrast.api.settings.Exclusion.MatchStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6443,
  serialized_end=6477,
)
_sym_db.RegisterEnumDescriptor(_EXCLUSION_MATCHSTRATEGY)

_VIRTUALPATCHCONDITION_INPUTTYPE = _descriptor.EnumDescriptor(
  name='InputType',
  full_name='contrast.api.settings.VirtualPatchCondition.InputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_INPUT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USERAGENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='URL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7000,
  serialized_end=7104,
)
_sym_db.RegisterEnumDescriptor(_VIRTUALPATCHCONDITION_INPUTTYPE)

_VIRTUALPATCHCONDITION_EVALUATION = _descriptor.EnumDescriptor(
  name='Evaluation',
  full_name='contrast.api.settings.VirtualPatchCondition.Evaluation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_EVALUATION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MATCHES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOESNT_MATCH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOESNT_CONTAIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUALS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOESNT_EQUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7107,
  serialized_end=7238,
)
_sym_db.RegisterEnumDescriptor(_VIRTUALPATCHCONDITION_EVALUATION)

_PROTECTIONRULE_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='contrast.api.settings.ProtectionRule.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_ACTION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONITOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_AT_PERIMETER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMIT', index=4, number=4,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7343,
  serialized_end=7428,
)
_sym_db.RegisterEnumDescriptor(_PROTECTIONRULE_MODE)

_AUTH_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='contrast.api.settings.Auth.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONITOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7608,
  serialized_end=7636,
)
_sym_db.RegisterEnumDescriptor(_AUTH_MODE)

_INPUTANALYSISRESULT_INPUTTYPE = _descriptor.EnumDescriptor(
  name='InputType',
  full_name='contrast.api.settings.InputAnalysisResult.InputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BODY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COOKIE_NAME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COOKIE_VALUE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER_NAME', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER_VALUE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUERYSTRING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='URI', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOCKET', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JSON_VALUE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JSON_ARRAYED_VALUE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTIPART_CONTENT_TYPE', index=12, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTIPART_VALUE', index=13, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTIPART_FIELD_NAME', index=14, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTIPART_NAME', index=15, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XML_VALUE', index=16, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DWR_VALUE', index=17, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METHOD', index=18, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REQUEST', index=19, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='URL_PARAMETER', index=20, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=21, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7985,
  serialized_end=8374,
)
_sym_db.RegisterEnumDescriptor(_INPUTANALYSISRESULT_INPUTTYPE)

_INPUTANALYSISRESULT_SCORELEVEL = _descriptor.EnumDescriptor(
  name='ScoreLevel',
  full_name='contrast.api.settings.InputAnalysisResult.ScoreLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DONTCARE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORTHWATCHING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEFINITEATTACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8376,
  serialized_end=8441,
)
_sym_db.RegisterEnumDescriptor(_INPUTANALYSISRESULT_SCORELEVEL)


_APPLICATIONSTATE = _descriptor.Descriptor(
  name='ApplicationState',
  full_name='contrast.api.settings.ApplicationState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created_ms', full_name='contrast.api.settings.ApplicationState.created_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='contrast.api.settings.ApplicationState.app_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_language', full_name='contrast.api.settings.ApplicationState.app_language', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_path', full_name='contrast.api.settings.ApplicationState.app_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_group', full_name='contrast.api.settings.ApplicationState.app_group', index=4,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_tags', full_name='contrast.api.settings.ApplicationState.app_tags', index=5,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='contrast.api.settings.ApplicationState.app_version', index=6,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_features', full_name='contrast.api.settings.ApplicationState.server_features', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_settings', full_name='contrast.api.settings.ApplicationState.application_settings', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulator_settings', full_name='contrast.api.settings.ApplicationState.accumulator_settings', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_name', full_name='contrast.api.settings.ApplicationState.server_name', index=10,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_path', full_name='contrast.api.settings.ApplicationState.server_path', index=11,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_type', full_name='contrast.api.settings.ApplicationState.server_type', index=12,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_tags', full_name='contrast.api.settings.ApplicationState.server_tags', index=13,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_environment', full_name='contrast.api.settings.ApplicationState.server_environment', index=14,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_version', full_name='contrast.api.settings.ApplicationState.server_version', index=15,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_version', full_name='contrast.api.settings.ApplicationState.agent_version', index=16,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=567,
)


_AGENTSETTINGS = _descriptor.Descriptor(
  name='AgentSettings',
  full_name='contrast.api.settings.AgentSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sent_ms', full_name='contrast.api.settings.AgentSettings.sent_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_features', full_name='contrast.api.settings.AgentSettings.server_features', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_settings', full_name='contrast.api.settings.AgentSettings.application_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulator_settings', full_name='contrast.api.settings.AgentSettings.accumulator_settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protect_state', full_name='contrast.api.settings.AgentSettings.protect_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_analysis', full_name='contrast.api.settings.AgentSettings.input_analysis', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=936,
)


_PROTECTSTATE = _descriptor.Descriptor(
  name='ProtectState',
  full_name='contrast.api.settings.ProtectState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='contrast.api.settings.ProtectState.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_request', full_name='contrast.api.settings.ProtectState.track_request', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_exception', full_name='contrast.api.settings.ProtectState.security_exception', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_message', full_name='contrast.api.settings.ProtectState.security_message', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1043,
)


_SERVERFEATURES = _descriptor.Descriptor(
  name='ServerFeatures',
  full_name='contrast.api.settings.ServerFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache', full_name='contrast.api.settings.ServerFeatures.cache', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_file', full_name='contrast.api.settings.ServerFeatures.log_file', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='contrast.api.settings.ServerFeatures.log_level', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='contrast.api.settings.ServerFeatures.inventory', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assess', full_name='contrast.api.settings.ServerFeatures.assess', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defend', full_name='contrast.api.settings.ServerFeatures.defend', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instrumentation_mode', full_name='contrast.api.settings.ServerFeatures.instrumentation_mode', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contrast_service', full_name='contrast.api.settings.ServerFeatures.contrast_service', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SERVERFEATURES_INSTRUMENTATIONMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1526,
)


_CONTRASTSERVICEDATA = _descriptor.Descriptor(
  name='ContrastServiceData',
  full_name='contrast.api.settings.ContrastServiceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='contrast.api.settings.ContrastServiceData.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1528,
  serialized_end=1566,
)


_APPLICATIONSETTINGS = _descriptor.Descriptor(
  name='ApplicationSettings',
  full_name='contrast.api.settings.ApplicationSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_patches', full_name='contrast.api.settings.ApplicationSettings.virtual_patches', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protection_rules', full_name='contrast.api.settings.ApplicationSettings.protection_rules', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclusions', full_name='contrast.api.settings.ApplicationSettings.exclusions', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled_assess_rules', full_name='contrast.api.settings.ApplicationSettings.disabled_assess_rules', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='contrast.api.settings.ApplicationSettings.reactions', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='contrast.api.settings.ApplicationSettings.session_id', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqli_settings', full_name='contrast.api.settings.ApplicationSettings.sqli_settings', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1569,
  serialized_end=1946,
)


_SQLINJECTIONSETTINGS = _descriptor.Descriptor(
  name='SqlInjectionSettings',
  full_name='contrast.api.settings.SqlInjectionSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detect_tautologies', full_name='contrast.api.settings.SqlInjectionSettings.detect_tautologies', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detect_chained_queries', full_name='contrast.api.settings.SqlInjectionSettings.detect_chained_queries', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detect_suspicious_unions', full_name='contrast.api.settings.SqlInjectionSettings.detect_suspicious_unions', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detect_dangerous_functions', full_name='contrast.api.settings.SqlInjectionSettings.detect_dangerous_functions', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1949,
  serialized_end=2101,
)


_REACTION = _descriptor.Descriptor(
  name='Reaction',
  full_name='contrast.api.settings.Reaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='contrast.api.settings.Reaction.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='contrast.api.settings.Reaction.log_level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='contrast.api.settings.Reaction.operation', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REACTION_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2104,
  serialized_end=2296,
)


_ACCUMULATORSETTINGS_ACCUMULATORSENTRY = _descriptor.Descriptor(
  name='AccumulatorsEntry',
  full_name='contrast.api.settings.AccumulatorSettings.AccumulatorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='contrast.api.settings.AccumulatorSettings.AccumulatorsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='contrast.api.settings.AccumulatorSettings.AccumulatorsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2406,
  serialized_end=2493,
)

_ACCUMULATORSETTINGS = _descriptor.Descriptor(
  name='AccumulatorSettings',
  full_name='contrast.api.settings.AccumulatorSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accumulators', full_name='contrast.api.settings.AccumulatorSettings.accumulators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ACCUMULATORSETTINGS_ACCUMULATORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2299,
  serialized_end=2493,
)


_INVENTORYFEATURES = _descriptor.Descriptor(
  name='InventoryFeatures',
  full_name='contrast.api.settings.InventoryFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='libraries', full_name='contrast.api.settings.InventoryFeatures.libraries', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activity', full_name='contrast.api.settings.InventoryFeatures.activity', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitor_db', full_name='contrast.api.settings.InventoryFeatures.monitor_db', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitor_ldap', full_name='contrast.api.settings.InventoryFeatures.monitor_ldap', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitor_web_calls', full_name='contrast.api.settings.InventoryFeatures.monitor_web_calls', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2495,
  serialized_end=2620,
)


_ASSESSFEATURES_DYNAMICSOURCESMAPENTRY = _descriptor.Descriptor(
  name='DynamicSourcesMapEntry',
  full_name='contrast.api.settings.AssessFeatures.DynamicSourcesMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='contrast.api.settings.AssessFeatures.DynamicSourcesMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='contrast.api.settings.AssessFeatures.DynamicSourcesMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3201,
  serialized_end=3295,
)

_ASSESSFEATURES = _descriptor.Descriptor(
  name='AssessFeatures',
  full_name='contrast.api.settings.AssessFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='contrast.api.settings.AssessFeatures.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_sources', full_name='contrast.api.settings.AssessFeatures.dynamic_sources', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='contrast.api.settings.AssessFeatures.sources', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='contrast.api.settings.AssessFeatures.rules', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='propagators', full_name='contrast.api.settings.AssessFeatures.propagators', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taggers', full_name='contrast.api.settings.AssessFeatures.taggers', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_scanning', full_name='contrast.api.settings.AssessFeatures.response_scanning', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stacktraces', full_name='contrast.api.settings.AssessFeatures.stacktraces', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_scopes', full_name='contrast.api.settings.AssessFeatures.validator_scopes', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity_tagging', full_name='contrast.api.settings.AssessFeatures.identity_tagging', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sanitizers', full_name='contrast.api.settings.AssessFeatures.sanitizers', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='contrast.api.settings.AssessFeatures.validators', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled_rules', full_name='contrast.api.settings.AssessFeatures.disabled_rules', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='contrast.api.settings.AssessFeatures.sampling', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_sources_map', full_name='contrast.api.settings.AssessFeatures.dynamic_sources_map', index=14,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ASSESSFEATURES_DYNAMICSOURCESMAPENTRY, ],
  enum_types=[
    _ASSESSFEATURES_SAVESTACKTRACE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2623,
  serialized_end=3357,
)


_CUSTOMRULEFEATURE = _descriptor.Descriptor(
  name='CustomRuleFeature',
  full_name='contrast.api.settings.CustomRuleFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api', full_name='contrast.api.settings.CustomRuleFeature.api', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='contrast.api.settings.CustomRuleFeature.tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='contrast.api.settings.CustomRuleFeature.rules', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3359,
  serialized_end=3420,
)


_SAMPLING = _descriptor.Descriptor(
  name='Sampling',
  full_name='contrast.api.settings.Sampling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='contrast.api.settings.Sampling.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseline', full_name='contrast.api.settings.Sampling.baseline', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_ms', full_name='contrast.api.settings.Sampling.window_ms', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_frequency', full_name='contrast.api.settings.Sampling.request_frequency', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_frequency', full_name='contrast.api.settings.Sampling.response_frequency', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3422,
  serialized_end=3541,
)


_DYNAMICSOURCE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='contrast.api.settings.DynamicSource.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='contrast.api.settings.DynamicSource.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='contrast.api.settings.DynamicSource.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3717,
  serialized_end=3766,
)

_DYNAMICSOURCE = _descriptor.Descriptor(
  name='DynamicSource',
  full_name='contrast.api.settings.DynamicSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='contrast.api.settings.DynamicSource.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='contrast.api.settings.DynamicSource.method_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_method', full_name='contrast.api.settings.DynamicSource.instance_method', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='contrast.api.settings.DynamicSource.target', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='contrast.api.settings.DynamicSource.properties', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DYNAMICSOURCE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3544,
  serialized_end=3766,
)


_DEFENDFEATURES = _descriptor.Descriptor(
  name='DefendFeatures',
  full_name='contrast.api.settings.DefendFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='contrast.api.settings.DefendFeatures.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_blocker', full_name='contrast.api.settings.DefendFeatures.bot_blocker', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_blockers', full_name='contrast.api.settings.DefendFeatures.bot_blockers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_blacklists', full_name='contrast.api.settings.DefendFeatures.ip_blacklists', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_denylists', full_name='contrast.api.settings.DefendFeatures.ip_denylists', index=4,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_whitelists', full_name='contrast.api.settings.DefendFeatures.ip_whitelists', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_allowlists', full_name='contrast.api.settings.DefendFeatures.ip_allowlists', index=6,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_enhancers', full_name='contrast.api.settings.DefendFeatures.log_enhancers', index=7,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule_definitions', full_name='contrast.api.settings.DefendFeatures.rule_definitions', index=8,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='syslog', full_name='contrast.api.settings.DefendFeatures.syslog', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='contrast.api.settings.DefendFeatures.auth', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3769,
  serialized_end=4325,
)


_SYSLOG = _descriptor.Descriptor(
  name='Syslog',
  full_name='contrast.api.settings.Syslog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='contrast.api.settings.Syslog.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='contrast.api.settings.Syslog.ip_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='contrast.api.settings.Syslog.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='facility_code', full_name='contrast.api.settings.Syslog.facility_code', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_type', full_name='contrast.api.settings.Syslog.connection_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity_exploited', full_name='contrast.api.settings.Syslog.severity_exploited', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity_blocked', full_name='contrast.api.settings.Syslog.severity_blocked', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity_probed', full_name='contrast.api.settings.Syslog.severity_probed', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity_blocked_perimeter', full_name='contrast.api.settings.Syslog.severity_blocked_perimeter', index=8,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity_probed_perimeter', full_name='contrast.api.settings.Syslog.severity_probed_perimeter', index=9,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='contrast.api.settings.Syslog.protocol', index=10,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='contrast.api.settings.Syslog.host', index=11,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYSLOG_CONNECTIONTYPE,
    _SYSLOG_SEVERITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4328,
  serialized_end=5041,
)


_BOTBLOCKER = _descriptor.Descriptor(
  name='BotBlocker',
  full_name='contrast.api.settings.BotBlocker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bot', full_name='contrast.api.settings.BotBlocker.bot', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_sensitive', full_name='contrast.api.settings.BotBlocker.case_sensitive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_anchor', full_name='contrast.api.settings.BotBlocker.start_anchor', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5043,
  serialized_end=5114,
)


_IPFILTER = _descriptor.Descriptor(
  name='IpFilter',
  full_name='contrast.api.settings.IpFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expires', full_name='contrast.api.settings.IpFilter.expires', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at_ms', full_name='contrast.api.settings.IpFilter.expires_at_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='contrast.api.settings.IpFilter.ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.IpFilter.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='contrast.api.settings.IpFilter.uuid', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5116,
  serialized_end=5206,
)


_LOGENHANCER = _descriptor.Descriptor(
  name='LogEnhancer',
  full_name='contrast.api.settings.LogEnhancer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='contrast.api.settings.LogEnhancer.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.LogEnhancer.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api', full_name='contrast.api.settings.LogEnhancer.api', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='contrast.api.settings.LogEnhancer.format', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='contrast.api.settings.LogEnhancer.log_level', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_type', full_name='contrast.api.settings.LogEnhancer.log_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGENHANCER_LOGLEVEL,
    _LOGENHANCER_LOGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5209,
  serialized_end=5527,
)


_RULEDEFINITION = _descriptor.Descriptor(
  name='RuleDefinition',
  full_name='contrast.api.settings.RuleDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.RuleDefinition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keywords', full_name='contrast.api.settings.RuleDefinition.keywords', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patterns', full_name='contrast.api.settings.RuleDefinition.patterns', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5530,
  serialized_end=5678,
)


_STRINGDEFINITION = _descriptor.Descriptor(
  name='StringDefinition',
  full_name='contrast.api.settings.StringDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='contrast.api.settings.StringDefinition.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule', full_name='contrast.api.settings.StringDefinition.rule', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='contrast.api.settings.StringDefinition.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='contrast.api.settings.StringDefinition.value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downcase', full_name='contrast.api.settings.StringDefinition.downcase', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_sensitive', full_name='contrast.api.settings.StringDefinition.case_sensitive', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='contrast.api.settings.StringDefinition.score', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STRINGDEFINITION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5681,
  serialized_end=5891,
)


_EXCLUSION = _descriptor.Descriptor(
  name='Exclusion',
  full_name='contrast.api.settings.Exclusion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='contrast.api.settings.Exclusion.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.Exclusion.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_strategy', full_name='contrast.api.settings.Exclusion.match_strategy', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modes', full_name='contrast.api.settings.Exclusion.modes', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protection_rules', full_name='contrast.api.settings.Exclusion.protection_rules', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assessment_rules', full_name='contrast.api.settings.Exclusion.assessment_rules', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='urls', full_name='contrast.api.settings.Exclusion.urls', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blacklist', full_name='contrast.api.settings.Exclusion.blacklist', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denylist', full_name='contrast.api.settings.Exclusion.denylist', index=8,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_type', full_name='contrast.api.settings.Exclusion.input_type', index=9,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_name', full_name='contrast.api.settings.Exclusion.input_name', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assess', full_name='contrast.api.settings.Exclusion.assess', index=11,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protect', full_name='contrast.api.settings.Exclusion.protect', index=12,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXCLUSION_EXCLUSIONTYPE,
    _EXCLUSION_INPUTTYPE,
    _EXCLUSION_MATCHSTRATEGY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5894,
  serialized_end=6477,
)


_VIRTUALPATCH = _descriptor.Descriptor(
  name='VirtualPatch',
  full_name='contrast.api.settings.VirtualPatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.VirtualPatch.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='contrast.api.settings.VirtualPatch.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='contrast.api.settings.VirtualPatch.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='contrast.api.settings.VirtualPatch.headers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='contrast.api.settings.VirtualPatch.parameters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='urls', full_name='contrast.api.settings.VirtualPatch.urls', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='contrast.api.settings.VirtualPatch.conditions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6480,
  serialized_end=6790,
)


_VIRTUALPATCHCONDITION = _descriptor.Descriptor(
  name='VirtualPatchCondition',
  full_name='contrast.api.settings.VirtualPatchCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.VirtualPatchCondition.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='contrast.api.settings.VirtualPatchCondition.value', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_type', full_name='contrast.api.settings.VirtualPatchCondition.input_type', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evaluation', full_name='contrast.api.settings.VirtualPatchCondition.evaluation', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VIRTUALPATCHCONDITION_INPUTTYPE,
    _VIRTUALPATCHCONDITION_EVALUATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6793,
  serialized_end=7238,
)


_PROTECTIONRULE = _descriptor.Descriptor(
  name='ProtectionRule',
  full_name='contrast.api.settings.ProtectionRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='contrast.api.settings.ProtectionRule.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.ProtectionRule.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='contrast.api.settings.ProtectionRule.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROTECTIONRULE_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7241,
  serialized_end=7428,
)


_ACCUMULATOR = _descriptor.Descriptor(
  name='Accumulator',
  full_name='contrast.api.settings.Accumulator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='contrast.api.settings.Accumulator.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='contrast.api.settings.Accumulator.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='contrast.api.settings.Accumulator.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_ms', full_name='contrast.api.settings.Accumulator.window_ms', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_ms', full_name='contrast.api.settings.Accumulator.created_ms', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_ms', full_name='contrast.api.settings.Accumulator.last_update_ms', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7430,
  serialized_end=7550,
)


_AUTH = _descriptor.Descriptor(
  name='Auth',
  full_name='contrast.api.settings.Auth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='contrast.api.settings.Auth.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUTH_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7552,
  serialized_end=7636,
)


_INPUTANALYSIS = _descriptor.Descriptor(
  name='InputAnalysis',
  full_name='contrast.api.settings.InputAnalysis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='contrast.api.settings.InputAnalysis.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7638,
  serialized_end=7714,
)


_INPUTANALYSISRESULT = _descriptor.Descriptor(
  name='InputAnalysisResult',
  full_name='contrast.api.settings.InputAnalysisResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_id', full_name='contrast.api.settings.InputAnalysisResult.rule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_type', full_name='contrast.api.settings.InputAnalysisResult.input_type', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='contrast.api.settings.InputAnalysisResult.path', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='contrast.api.settings.InputAnalysisResult.key', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='contrast.api.settings.InputAnalysisResult.value', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score_level', full_name='contrast.api.settings.InputAnalysisResult.score_level', index=5,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ids', full_name='contrast.api.settings.InputAnalysisResult.ids', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attack_count', full_name='contrast.api.settings.InputAnalysisResult.attack_count', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INPUTANALYSISRESULT_INPUTTYPE,
    _INPUTANALYSISRESULT_SCORELEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7717,
  serialized_end=8441,
)

_APPLICATIONSTATE.fields_by_name['server_features'].message_type = _SERVERFEATURES
_APPLICATIONSTATE.fields_by_name['application_settings'].message_type = _APPLICATIONSETTINGS
_APPLICATIONSTATE.fields_by_name['accumulator_settings'].message_type = _ACCUMULATORSETTINGS
_AGENTSETTINGS.fields_by_name['server_features'].message_type = _SERVERFEATURES
_AGENTSETTINGS.fields_by_name['application_settings'].message_type = _APPLICATIONSETTINGS
_AGENTSETTINGS.fields_by_name['accumulator_settings'].message_type = _ACCUMULATORSETTINGS
_AGENTSETTINGS.fields_by_name['protect_state'].message_type = _PROTECTSTATE
_AGENTSETTINGS.fields_by_name['input_analysis'].message_type = _INPUTANALYSIS
_SERVERFEATURES.fields_by_name['inventory'].message_type = _INVENTORYFEATURES
_SERVERFEATURES.fields_by_name['assess'].message_type = _ASSESSFEATURES
_SERVERFEATURES.fields_by_name['defend'].message_type = _DEFENDFEATURES
_SERVERFEATURES.fields_by_name['instrumentation_mode'].enum_type = _SERVERFEATURES_INSTRUMENTATIONMODE
_SERVERFEATURES.fields_by_name['contrast_service'].message_type = _CONTRASTSERVICEDATA
_SERVERFEATURES_INSTRUMENTATIONMODE.containing_type = _SERVERFEATURES
_APPLICATIONSETTINGS.fields_by_name['virtual_patches'].message_type = _VIRTUALPATCH
_APPLICATIONSETTINGS.fields_by_name['protection_rules'].message_type = _PROTECTIONRULE
_APPLICATIONSETTINGS.fields_by_name['exclusions'].message_type = _EXCLUSION
_APPLICATIONSETTINGS.fields_by_name['reactions'].message_type = _REACTION
_APPLICATIONSETTINGS.fields_by_name['sqli_settings'].message_type = _SQLINJECTIONSETTINGS
_REACTION.fields_by_name['log_level'].enum_type = _LOGLEVEL
_REACTION.fields_by_name['operation'].enum_type = _REACTION_OPERATION
_REACTION_OPERATION.containing_type = _REACTION
_ACCUMULATORSETTINGS_ACCUMULATORSENTRY.fields_by_name['value'].message_type = _ACCUMULATOR
_ACCUMULATORSETTINGS_ACCUMULATORSENTRY.containing_type = _ACCUMULATORSETTINGS
_ACCUMULATORSETTINGS.fields_by_name['accumulators'].message_type = _ACCUMULATORSETTINGS_ACCUMULATORSENTRY
_ASSESSFEATURES_DYNAMICSOURCESMAPENTRY.fields_by_name['value'].message_type = _DYNAMICSOURCE
_ASSESSFEATURES_DYNAMICSOURCESMAPENTRY.containing_type = _ASSESSFEATURES
_ASSESSFEATURES.fields_by_name['stacktraces'].enum_type = _ASSESSFEATURES_SAVESTACKTRACE
_ASSESSFEATURES.fields_by_name['sanitizers'].message_type = _CUSTOMRULEFEATURE
_ASSESSFEATURES.fields_by_name['validators'].message_type = _CUSTOMRULEFEATURE
_ASSESSFEATURES.fields_by_name['sampling'].message_type = _SAMPLING
_ASSESSFEATURES.fields_by_name['dynamic_sources_map'].message_type = _ASSESSFEATURES_DYNAMICSOURCESMAPENTRY
_ASSESSFEATURES_SAVESTACKTRACE.containing_type = _ASSESSFEATURES
_DYNAMICSOURCE_PROPERTIESENTRY.containing_type = _DYNAMICSOURCE
_DYNAMICSOURCE.fields_by_name['properties'].message_type = _DYNAMICSOURCE_PROPERTIESENTRY
_DEFENDFEATURES.fields_by_name['bot_blockers'].message_type = _BOTBLOCKER
_DEFENDFEATURES.fields_by_name['ip_blacklists'].message_type = _IPFILTER
_DEFENDFEATURES.fields_by_name['ip_denylists'].message_type = _IPFILTER
_DEFENDFEATURES.fields_by_name['ip_whitelists'].message_type = _IPFILTER
_DEFENDFEATURES.fields_by_name['ip_allowlists'].message_type = _IPFILTER
_DEFENDFEATURES.fields_by_name['log_enhancers'].message_type = _LOGENHANCER
_DEFENDFEATURES.fields_by_name['rule_definitions'].message_type = _RULEDEFINITION
_DEFENDFEATURES.fields_by_name['syslog'].message_type = _SYSLOG
_DEFENDFEATURES.fields_by_name['auth'].message_type = _AUTH
_SYSLOG.fields_by_name['connection_type'].enum_type = _SYSLOG_CONNECTIONTYPE
_SYSLOG.fields_by_name['severity_exploited'].enum_type = _SYSLOG_SEVERITY
_SYSLOG.fields_by_name['severity_blocked'].enum_type = _SYSLOG_SEVERITY
_SYSLOG.fields_by_name['severity_probed'].enum_type = _SYSLOG_SEVERITY
_SYSLOG.fields_by_name['severity_blocked_perimeter'].enum_type = _SYSLOG_SEVERITY
_SYSLOG.fields_by_name['severity_probed_perimeter'].enum_type = _SYSLOG_SEVERITY
_SYSLOG_CONNECTIONTYPE.containing_type = _SYSLOG
_SYSLOG_SEVERITY.containing_type = _SYSLOG
_LOGENHANCER.fields_by_name['log_level'].enum_type = _LOGENHANCER_LOGLEVEL
_LOGENHANCER.fields_by_name['log_type'].enum_type = _LOGENHANCER_LOGTYPE
_LOGENHANCER_LOGLEVEL.containing_type = _LOGENHANCER
_LOGENHANCER_LOGTYPE.containing_type = _LOGENHANCER
_RULEDEFINITION.fields_by_name['keywords'].message_type = _STRINGDEFINITION
_RULEDEFINITION.fields_by_name['patterns'].message_type = _STRINGDEFINITION
_STRINGDEFINITION.fields_by_name['type'].enum_type = _STRINGDEFINITION_TYPE
_STRINGDEFINITION_TYPE.containing_type = _STRINGDEFINITION
_EXCLUSION.fields_by_name['type'].enum_type = _EXCLUSION_EXCLUSIONTYPE
_EXCLUSION.fields_by_name['match_strategy'].enum_type = _EXCLUSION_MATCHSTRATEGY
_EXCLUSION.fields_by_name['input_type'].enum_type = _EXCLUSION_INPUTTYPE
_EXCLUSION_EXCLUSIONTYPE.containing_type = _EXCLUSION
_EXCLUSION_INPUTTYPE.containing_type = _EXCLUSION
_EXCLUSION_MATCHSTRATEGY.containing_type = _EXCLUSION
_VIRTUALPATCH.fields_by_name['headers'].message_type = _VIRTUALPATCHCONDITION
_VIRTUALPATCH.fields_by_name['parameters'].message_type = _VIRTUALPATCHCONDITION
_VIRTUALPATCH.fields_by_name['urls'].message_type = _VIRTUALPATCHCONDITION
_VIRTUALPATCH.fields_by_name['conditions'].message_type = _VIRTUALPATCHCONDITION
_VIRTUALPATCHCONDITION.fields_by_name['input_type'].enum_type = _VIRTUALPATCHCONDITION_INPUTTYPE
_VIRTUALPATCHCONDITION.fields_by_name['evaluation'].enum_type = _VIRTUALPATCHCONDITION_EVALUATION
_VIRTUALPATCHCONDITION_INPUTTYPE.containing_type = _VIRTUALPATCHCONDITION
_VIRTUALPATCHCONDITION_EVALUATION.containing_type = _VIRTUALPATCHCONDITION
_PROTECTIONRULE.fields_by_name['mode'].enum_type = _PROTECTIONRULE_MODE
_PROTECTIONRULE_MODE.containing_type = _PROTECTIONRULE
_AUTH.fields_by_name['mode'].enum_type = _AUTH_MODE
_AUTH_MODE.containing_type = _AUTH
_INPUTANALYSIS.fields_by_name['results'].message_type = _INPUTANALYSISRESULT
_INPUTANALYSISRESULT.fields_by_name['input_type'].enum_type = _INPUTANALYSISRESULT_INPUTTYPE
_INPUTANALYSISRESULT.fields_by_name['score_level'].enum_type = _INPUTANALYSISRESULT_SCORELEVEL
_INPUTANALYSISRESULT_INPUTTYPE.containing_type = _INPUTANALYSISRESULT
_INPUTANALYSISRESULT_SCORELEVEL.containing_type = _INPUTANALYSISRESULT
DESCRIPTOR.message_types_by_name['ApplicationState'] = _APPLICATIONSTATE
DESCRIPTOR.message_types_by_name['AgentSettings'] = _AGENTSETTINGS
DESCRIPTOR.message_types_by_name['ProtectState'] = _PROTECTSTATE
DESCRIPTOR.message_types_by_name['ServerFeatures'] = _SERVERFEATURES
DESCRIPTOR.message_types_by_name['ContrastServiceData'] = _CONTRASTSERVICEDATA
DESCRIPTOR.message_types_by_name['ApplicationSettings'] = _APPLICATIONSETTINGS
DESCRIPTOR.message_types_by_name['SqlInjectionSettings'] = _SQLINJECTIONSETTINGS
DESCRIPTOR.message_types_by_name['Reaction'] = _REACTION
DESCRIPTOR.message_types_by_name['AccumulatorSettings'] = _ACCUMULATORSETTINGS
DESCRIPTOR.message_types_by_name['InventoryFeatures'] = _INVENTORYFEATURES
DESCRIPTOR.message_types_by_name['AssessFeatures'] = _ASSESSFEATURES
DESCRIPTOR.message_types_by_name['CustomRuleFeature'] = _CUSTOMRULEFEATURE
DESCRIPTOR.message_types_by_name['Sampling'] = _SAMPLING
DESCRIPTOR.message_types_by_name['DynamicSource'] = _DYNAMICSOURCE
DESCRIPTOR.message_types_by_name['DefendFeatures'] = _DEFENDFEATURES
DESCRIPTOR.message_types_by_name['Syslog'] = _SYSLOG
DESCRIPTOR.message_types_by_name['BotBlocker'] = _BOTBLOCKER
DESCRIPTOR.message_types_by_name['IpFilter'] = _IPFILTER
DESCRIPTOR.message_types_by_name['LogEnhancer'] = _LOGENHANCER
DESCRIPTOR.message_types_by_name['RuleDefinition'] = _RULEDEFINITION
DESCRIPTOR.message_types_by_name['StringDefinition'] = _STRINGDEFINITION
DESCRIPTOR.message_types_by_name['Exclusion'] = _EXCLUSION
DESCRIPTOR.message_types_by_name['VirtualPatch'] = _VIRTUALPATCH
DESCRIPTOR.message_types_by_name['VirtualPatchCondition'] = _VIRTUALPATCHCONDITION
DESCRIPTOR.message_types_by_name['ProtectionRule'] = _PROTECTIONRULE
DESCRIPTOR.message_types_by_name['Accumulator'] = _ACCUMULATOR
DESCRIPTOR.message_types_by_name['Auth'] = _AUTH
DESCRIPTOR.message_types_by_name['InputAnalysis'] = _INPUTANALYSIS
DESCRIPTOR.message_types_by_name['InputAnalysisResult'] = _INPUTANALYSISRESULT
DESCRIPTOR.enum_types_by_name['LogLevel'] = _LOGLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApplicationState = _reflection.GeneratedProtocolMessageType('ApplicationState', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONSTATE,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.ApplicationState)
  })
_sym_db.RegisterMessage(ApplicationState)

AgentSettings = _reflection.GeneratedProtocolMessageType('AgentSettings', (_message.Message,), {
  'DESCRIPTOR' : _AGENTSETTINGS,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.AgentSettings)
  })
_sym_db.RegisterMessage(AgentSettings)

ProtectState = _reflection.GeneratedProtocolMessageType('ProtectState', (_message.Message,), {
  'DESCRIPTOR' : _PROTECTSTATE,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.ProtectState)
  })
_sym_db.RegisterMessage(ProtectState)

ServerFeatures = _reflection.GeneratedProtocolMessageType('ServerFeatures', (_message.Message,), {
  'DESCRIPTOR' : _SERVERFEATURES,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.ServerFeatures)
  })
_sym_db.RegisterMessage(ServerFeatures)

ContrastServiceData = _reflection.GeneratedProtocolMessageType('ContrastServiceData', (_message.Message,), {
  'DESCRIPTOR' : _CONTRASTSERVICEDATA,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.ContrastServiceData)
  })
_sym_db.RegisterMessage(ContrastServiceData)

ApplicationSettings = _reflection.GeneratedProtocolMessageType('ApplicationSettings', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONSETTINGS,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.ApplicationSettings)
  })
_sym_db.RegisterMessage(ApplicationSettings)

SqlInjectionSettings = _reflection.GeneratedProtocolMessageType('SqlInjectionSettings', (_message.Message,), {
  'DESCRIPTOR' : _SQLINJECTIONSETTINGS,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.SqlInjectionSettings)
  })
_sym_db.RegisterMessage(SqlInjectionSettings)

Reaction = _reflection.GeneratedProtocolMessageType('Reaction', (_message.Message,), {
  'DESCRIPTOR' : _REACTION,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.Reaction)
  })
_sym_db.RegisterMessage(Reaction)

AccumulatorSettings = _reflection.GeneratedProtocolMessageType('AccumulatorSettings', (_message.Message,), {

  'AccumulatorsEntry' : _reflection.GeneratedProtocolMessageType('AccumulatorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACCUMULATORSETTINGS_ACCUMULATORSENTRY,
    '__module__' : 'settings_pb2'
    # @@protoc_insertion_point(class_scope:contrast.api.settings.AccumulatorSettings.AccumulatorsEntry)
    })
  ,
  'DESCRIPTOR' : _ACCUMULATORSETTINGS,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.AccumulatorSettings)
  })
_sym_db.RegisterMessage(AccumulatorSettings)
_sym_db.RegisterMessage(AccumulatorSettings.AccumulatorsEntry)

InventoryFeatures = _reflection.GeneratedProtocolMessageType('InventoryFeatures', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYFEATURES,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.InventoryFeatures)
  })
_sym_db.RegisterMessage(InventoryFeatures)

AssessFeatures = _reflection.GeneratedProtocolMessageType('AssessFeatures', (_message.Message,), {

  'DynamicSourcesMapEntry' : _reflection.GeneratedProtocolMessageType('DynamicSourcesMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _ASSESSFEATURES_DYNAMICSOURCESMAPENTRY,
    '__module__' : 'settings_pb2'
    # @@protoc_insertion_point(class_scope:contrast.api.settings.AssessFeatures.DynamicSourcesMapEntry)
    })
  ,
  'DESCRIPTOR' : _ASSESSFEATURES,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.AssessFeatures)
  })
_sym_db.RegisterMessage(AssessFeatures)
_sym_db.RegisterMessage(AssessFeatures.DynamicSourcesMapEntry)

CustomRuleFeature = _reflection.GeneratedProtocolMessageType('CustomRuleFeature', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMRULEFEATURE,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.CustomRuleFeature)
  })
_sym_db.RegisterMessage(CustomRuleFeature)

Sampling = _reflection.GeneratedProtocolMessageType('Sampling', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLING,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.Sampling)
  })
_sym_db.RegisterMessage(Sampling)

DynamicSource = _reflection.GeneratedProtocolMessageType('DynamicSource', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DYNAMICSOURCE_PROPERTIESENTRY,
    '__module__' : 'settings_pb2'
    # @@protoc_insertion_point(class_scope:contrast.api.settings.DynamicSource.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _DYNAMICSOURCE,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.DynamicSource)
  })
_sym_db.RegisterMessage(DynamicSource)
_sym_db.RegisterMessage(DynamicSource.PropertiesEntry)

DefendFeatures = _reflection.GeneratedProtocolMessageType('DefendFeatures', (_message.Message,), {
  'DESCRIPTOR' : _DEFENDFEATURES,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.DefendFeatures)
  })
_sym_db.RegisterMessage(DefendFeatures)

Syslog = _reflection.GeneratedProtocolMessageType('Syslog', (_message.Message,), {
  'DESCRIPTOR' : _SYSLOG,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.Syslog)
  })
_sym_db.RegisterMessage(Syslog)

BotBlocker = _reflection.GeneratedProtocolMessageType('BotBlocker', (_message.Message,), {
  'DESCRIPTOR' : _BOTBLOCKER,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.BotBlocker)
  })
_sym_db.RegisterMessage(BotBlocker)

IpFilter = _reflection.GeneratedProtocolMessageType('IpFilter', (_message.Message,), {
  'DESCRIPTOR' : _IPFILTER,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.IpFilter)
  })
_sym_db.RegisterMessage(IpFilter)

LogEnhancer = _reflection.GeneratedProtocolMessageType('LogEnhancer', (_message.Message,), {
  'DESCRIPTOR' : _LOGENHANCER,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.LogEnhancer)
  })
_sym_db.RegisterMessage(LogEnhancer)

RuleDefinition = _reflection.GeneratedProtocolMessageType('RuleDefinition', (_message.Message,), {
  'DESCRIPTOR' : _RULEDEFINITION,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.RuleDefinition)
  })
_sym_db.RegisterMessage(RuleDefinition)

StringDefinition = _reflection.GeneratedProtocolMessageType('StringDefinition', (_message.Message,), {
  'DESCRIPTOR' : _STRINGDEFINITION,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.StringDefinition)
  })
_sym_db.RegisterMessage(StringDefinition)

Exclusion = _reflection.GeneratedProtocolMessageType('Exclusion', (_message.Message,), {
  'DESCRIPTOR' : _EXCLUSION,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.Exclusion)
  })
_sym_db.RegisterMessage(Exclusion)

VirtualPatch = _reflection.GeneratedProtocolMessageType('VirtualPatch', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALPATCH,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.VirtualPatch)
  })
_sym_db.RegisterMessage(VirtualPatch)

VirtualPatchCondition = _reflection.GeneratedProtocolMessageType('VirtualPatchCondition', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALPATCHCONDITION,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.VirtualPatchCondition)
  })
_sym_db.RegisterMessage(VirtualPatchCondition)

ProtectionRule = _reflection.GeneratedProtocolMessageType('ProtectionRule', (_message.Message,), {
  'DESCRIPTOR' : _PROTECTIONRULE,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.ProtectionRule)
  })
_sym_db.RegisterMessage(ProtectionRule)

Accumulator = _reflection.GeneratedProtocolMessageType('Accumulator', (_message.Message,), {
  'DESCRIPTOR' : _ACCUMULATOR,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.Accumulator)
  })
_sym_db.RegisterMessage(Accumulator)

Auth = _reflection.GeneratedProtocolMessageType('Auth', (_message.Message,), {
  'DESCRIPTOR' : _AUTH,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.Auth)
  })
_sym_db.RegisterMessage(Auth)

InputAnalysis = _reflection.GeneratedProtocolMessageType('InputAnalysis', (_message.Message,), {
  'DESCRIPTOR' : _INPUTANALYSIS,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.InputAnalysis)
  })
_sym_db.RegisterMessage(InputAnalysis)

InputAnalysisResult = _reflection.GeneratedProtocolMessageType('InputAnalysisResult', (_message.Message,), {
  'DESCRIPTOR' : _INPUTANALYSISRESULT,
  '__module__' : 'settings_pb2'
  # @@protoc_insertion_point(class_scope:contrast.api.settings.InputAnalysisResult)
  })
_sym_db.RegisterMessage(InputAnalysisResult)


DESCRIPTOR._options = None
_APPLICATIONSETTINGS.fields_by_name['session_id']._options = None
_ACCUMULATORSETTINGS_ACCUMULATORSENTRY._options = None
_ASSESSFEATURES_DYNAMICSOURCESMAPENTRY._options = None
_ASSESSFEATURES.fields_by_name['disabled_rules']._options = None
_DYNAMICSOURCE_PROPERTIESENTRY._options = None
_DEFENDFEATURES.fields_by_name['ip_blacklists']._options = None
_DEFENDFEATURES.fields_by_name['ip_whitelists']._options = None
_SYSLOG_CONNECTIONTYPE.values_by_name["ENCRYOTED"]._options = None
_EXCLUSION.fields_by_name['match_strategy']._options = None
_EXCLUSION.fields_by_name['modes']._options = None
_EXCLUSION.fields_by_name['blacklist']._options = None
_PROTECTIONRULE_MODE.values_by_name["PERMIT"]._options = None
# @@protoc_insertion_point(module_scope)
